@@ -30,7 +30,16 @@ class Payment(APIView):
         })
 
     def pay(self):
+        token = self.META.get('HTTP_AUTHORIZATION', '')
+        if not token:
+            return util_response(err=4001, msg='缺少Token')
+
+        data, err_txt = UserService.check_token(token)
+        if err_txt:
+            return util_response(err=47766, msg=err_txt)
         params = parse_data(self)
+        params['platform_id'] = data['platform_id']
+        # print(params)
         payment = PaymentService.pay(params)
         return JsonResponse({
             'err': 0,
