@@ -22,8 +22,10 @@ class PaymentStatus(models.Model):
 class PaymentPayment(models.Model):
     # id = models.AutoField(verbose_name='id', blank=True, null=False, db_index=True)
     order_no = models.BigIntegerField(verbose_name='订单号', blank=True, null=False, db_index=True)
-    transact_no = models.IntegerField(verbose_name='流水号', blank=True, null=False, db_index=True)
-    transact_id = models.IntegerField(verbose_name='资金id', blank=True, null=True, db_index=True)
+    # transact_no = models.IntegerField(verbose_name='流水号', blank=True, null=False, db_index=True)
+    transact_no = models.CharField(verbose_name='交易号', max_length=128, blank=True, null=True, db_index=True)
+    # transact_id = models.IntegerField(verbose_name='资金id', blank=True, null=True, db_index=True)
+    transact_id = models.CharField(verbose_name='资金交易ID', max_length=128, blank=True, null=True, db_index=True)
     enroll_id = models.IntegerField(verbose_name='报名id', blank=True, null=False, db_index=True)
     order_id = models.IntegerField(verbose_name='订单id', blank=True, null=False, db_index=True)
     user_id = models.IntegerField(verbose_name='用户id', blank=True, null=True, db_index=True)
