@@ -12,6 +12,8 @@ from django.forms import model_to_dict
 from django.utils import timezone
 from pathlib import Path
 from main.settings import BASE_DIR
+from xj_user.models import Platform
+from xj_user.services.user_platform_service import UserPlatformService
 from ..utils.j_config import JConfig
 from ..utils.j_dict import JDict
 from xj_finance.services.finance_service import FinanceService
@@ -119,12 +121,22 @@ class PaymentService:
             "total_amount": int(data['total_fee']),
             "create_time": now,
         }
-        data['platform'] = merchant_name
+
+        platform_set, err = UserPlatformService.payment_get_platform_info(params['platform_id'])
+        if err:
+            data['platform'] = merchant_name
+        else:
+            data['platform'] = platform_set['platform_name']
+
+
         data['currency'] = 'CNY'
 
         if params.get("total_amount", 0):
             data['total_fee'] = float(params.get("total_amount", 0)) * 100  # 元转分
 
+        if data['total_fee'] < 1:
+            return "支付金额不能小于一分钱"
+
         PaymentPayment.objects.create(**payment_data)
         # 支付方式检查
         if params['payment_method'] == "applets":  # 微信小程序支付
@@ -136,6 +148,8 @@ class PaymentService:
 
         elif params['payment_method'] == "balance":  # 余额支付
             payment = PaymentWechatService.payment_balance_pay(data)
+        else:
+            payment = "支付方式不存在"
 
         return payment
 
@@ -150,5 +164,7 @@ class PaymentService:
         # 支付方式检查
         if params['payment_method'] == "WECHAT":  # 微信退款
             payment = PaymentWechatService.payment_refund(data)
+        else:
+            payment = "退款方式不存在"
 
         return payment
