@@ -22,6 +22,9 @@ from ..models import PaymentPayment
 from ..utils.j_config import JConfig
 from ..utils.j_dict import JDict
 from ..utils.wechat_utils import my_ali_pay, my_ali_pay_v3, to_text, random_string, applets_red_envelopes
+from logging import getLogger
+
+logger = getLogger('log')
 
 module_root = str(Path(__file__).resolve().parent)
 # 配置之对象
@@ -374,12 +377,13 @@ class PaymentWechatService:
                 "amount": float("-" + str(total_amount)),
                 "currency": "CNY",
                 "pay_mode": "WECHAT",
-                "finance_status_code": 2
+                "finance_status_code": 5  # 资金状态码 finance_status_code 124 已下单支付 待接单
 
             }
             # 根据订单号查询支付记录是否存在
             payment = PaymentPayment.objects.filter(order_no=int(out_trade_no)).first()
             if not payment:
+                logger.info(">>>>payment_logic_processing" + "支付记录不存在")
                 logging.debug(">>>>payment_logic_processing" + "支付记录不存在")
             payment_message = model_to_dict(payment)
             finance_data['account_id'] = payment_message['user_id']
@@ -406,6 +410,7 @@ class PaymentWechatService:
             funance_add_data, err_txt = FinanceTransactService.post(finance_data)
             if err_txt:
                 print(">>>>payment_logic_processing_err", err_txt)
+                logger.info(">>>>payment_logic_processing" + "写入资金模块失败（用户支付）")
                 logging.debug(">>>>payment_logic_processing" + "写入资金模块失败（用户支付）")
                 raise Networkerror("Bad hostname")
             # 根据唯一交易id 查询主键id
@@ -433,11 +438,12 @@ class PaymentWechatService:
                         'full_name'] + "】项目名称【" + project_name + "】款项",
                     "currency": "CNY",
                     "pay_mode": "BALANCE",
-                    "finance_status_code": 2
+                    "finance_status_code": 5  # 资金状态码 finance_status_code 124 已下单支付 待接单
                 }
                 finance_platform_data_set, finance_platform_err = FinanceTransactService.post(platform_revenue_data)
                 if finance_platform_err:
                     print(">>>>payment_logic_processing_err", finance_platform_err)
+                    logger.info(">>>>payment_logic_processing" + "写入资金模块失败（平台收入）")
                     logging.debug(">>>>payment_logic_processing" + "写入资金模块失败（平台收入）")
                     raise Networkerror("Bad hostname")
                 # 更改支付记录
@@ -445,12 +451,15 @@ class PaymentWechatService:
                 # 报名表支付状态修改
                 pay_call_back_data, pay_call_back_err = EnrollServices.pay_call_back(out_trade_no)
                 if pay_call_back_err:
+                    logger.info(">>>>报名修改失败" + pay_call_back_err)
                     logging.debug(">>>>报名修改失败" + pay_call_back_err)
 
         except Networkerror as t:
+            logger.info("支付回调异常1：", t)
             print("支付回调异常1：", t)
             transaction.savepoint_rollback(sid)
         except Exception as e:
+            logger.info("支付回调异常2：", e)
             print("支付回调异常2：", e)
             transaction.savepoint_rollback(sid)
             logging.debug("payment_logic_processing" + e)
