@@ -1,7 +1,7 @@
 # 应用名称
 from django.urls import re_path
 
-from xj_payment.apis import alipay, transaction_inquiry, wechat, payment
+from xj_payment.apis import alipay, transaction_inquiry, wechat, payment, payment_status
 from .apis import payment_alipay
 from .apis import payment_wechat
 from .apis import payment_unionpay
@@ -27,19 +27,20 @@ urlpatterns = [
     re_path(r'^get_user_info/?$', payment_wechat.PaymentWechat.get_user_info),  # 获取用户标识接口
     re_path(r'^applets_pay/?$', payment_wechat.PaymentWechat.payment_applets_pay),  # 小程序支付接口
     re_path(r'^wechat_py/?$', wechat.WeChatPayment.pay),  # 微信支付接口
-    # re_path(r'^wechat_pay/?$', payment.WechatPayDAL.create_order_info),  # 微信支付接口
     re_path(r'^scan_pay/?$', payment_wechat.PaymentWechat.payment_scan_pay),  # 微信扫码支付
     re_path(r'^red_envelopes/?$', payment_wechat.PaymentWechat.payment_red_envelopes),  # 微信红包
-    re_path(r'^wechat_callback/?$', payment_wechat.PaymentWechat.callback),  # 回调接口
-    re_path(r'^wechat_callback_v3/?$', payment_wechat.PaymentWechat.callback_v3),  # 回调接口v3
+    re_path(r'^wechat_callback/?$', payment_wechat.PaymentWechat.callback),  # 微信回调接口
+    re_path(r'^wechat_callback_v3/?$', payment_wechat.PaymentWechat.callback_v3),  # 微信回调接口v3
 
     re_path(r'^unipay/?$', payment_unionpay.PaymentUnionPay.unipay),
 
-    re_path(r'^pay/?$', payment.Payment.pay),
+    re_path(r'^pay/?$', payment.Payment.pay),  # 支付总接接口
 
     re_path(r'^refund/?$', payment.Payment.refund),
 
-    re_path(r'^list/?$', payment.Payment.get),
+    re_path(r'^list/?$', payment.Payment.get),  # 支付列表
+
+    re_path(r'^status/?$', payment_status.PaymentStatus.as_view()),  # 支付状态列表
 
     # re_path(r'^pay/?$', wechat_payment.WeChatPayment.pay),
     # re_path(r'^pay/?$', wechat.WeChatPayment.pay),
